@@ -38,8 +38,9 @@ public:
     //* restart
     void restart()
     {
-        if (isRunning())
+        if (isRunning()) {
             stop();
+        }
         start();
     }
 };
